/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 09043
 |          POLICY RESEARCH ON AGING AND MENTAL HEALTH SERVICES
 |                            (PRAMHS) PROJECT
 |                 (DATASET 0002: AREA AGENCIES ON AGING)
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 09043-0002-statasetup.do)
 |
 **************************************************************************/

set mem 6m  /* Allocating 6 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.

**********************************************************/


label data "Policy Research on Aging and Mental Health Services (PRAMHS) Project, Dataset 0002"

#delimit ;
label define CASEID    1 "Unique sequential id" 349 "Unique sequential id" ;
label define V5        1 "Alabama" 2 "Alaska" 3 "Arizona" 4 "Arkansas"
                       5 "California" 6 "Colorado" 7 "Connecticut"
                       8 "Delaware" 9 "District of Columbia" 10 "Florida"
                       11 "Georgia" 12 "Hawaii" 13 "Idaho" 14 "Illinois"
                       15 "Indiana" 16 "Iowa" 17 "Kansas" 18 "Kentucky"
                       19 "Louisiana" 20 "Maine" 21 "Maryland"
                       22 "Massachusetts" 23 "Michigan" 24 "Minnesota"
                       25 "Mississippi" 26 "Missouri" 27 "Montana"
                       28 "Nebraska" 29 "Nevada" 30 "New Hampshire"
                       31 "New Jersey" 32 "New Mexico" 33 "New York"
                       34 "North Carolina" 35 "North Dakota" 36 "Ohio"
                       37 "Oklahoma" 38 "Oregon" 39 "Pennsylvania"
                       40 "Rhode Island" 41 "South Carolina"
                       42 "South Dakota" 43 "Tennessee" 44 "Texas" 45 "Utah"
                       46 "Vermont" 47 "Virginia" 48 "Washington"
                       49 "West Virginia" 50 "Wisconsin" 51 "Wyoming"
                       52 "American Samoa" 53 "Guam" 54 "Puerto Rico"
                       55 "Virgin Islands" 56 "Marianna Islands"
                       57 "North Marianna Islands" ;
label define V6        1 "Area agency on aging" 2 "State unit on aging"
                       3 "Community mental health centers"
                       4 "State mental health agency" ;
label define V7        2 "Agency 2" 602 "Agency 602" ;
label define V8        0 "Less than one year" 15 "Fifteen years" 99 "N/A" ;
label define V9        1 "Private non-profit" 2 "Regional planning body"
                       3 "Other" 9 "N/A" ;
label define V10       0 "None" 52456 "Thousand dollars" 99999 "N/A" ;
label define V11       0 "None" 5300 "Thousand dollars" 9999 "N/A" ;
label define V12       0 "None" 33 "Thirty three percent" 99 "N/A" ;
label define V13       0 "None" 99 "Number of full-time professional staff"
                       999 "N/A" ;
label define V14       0 "None" 99 "Number of part-time professional staff"
                       999 "N/A" ;
label define V15       0 "None" 85 "Number of full-time support staff"
                       99 "N/A" ;
label define V16       0 "None" 99 "Number of part-time support staff"
                       999 "N/A" ;
label define V17       0 "None" 99 "Number of volunteers" 999 "N/A" ;
label define V18       0 "None" 99 "Ninety nine percent" 999 "N/A" ;
label define V19       0 "None" 99 "Ninety nine percent" 999 "N/A" ;
label define V20       1 "Yes" 2 "No" 9 "N/A" ;
label define V21       0 "None" 99 "Ninety nine percent" 999 "N/A" ;
label define V22       0 "None" 99 "Ninety nine percent" 999 "N/A" ;
label define V23       0 "None" 99 "Ninety nine percent" 999 "N/A" ;
label define V24       0 "None" 99 "Ninety nine percent" 999 "N/A" ;
label define V25       0 "None" 99 "Ninety nine percent" 999 "N/A" ;
label define V26       0 "None" 99 "Ninety nine percent" 999 "N/A" ;
label define V27       0 "None" 99 "Ninety nine percent" 999 "N/A" ;
label define V28       1 "Yes" 2 "No" 9 "N/A" ;
label define V29       1 "Yes" 2 "No" 9 "N/A" ;
label define V30       1 "Yes" 2 "No" 9 "N/A" ;
label define V31       1 "Yes" 2 "No" 9 "N/A" ;
label define V32       1 "No contact" 2 "Less often" 3 "Monthly" 4 "Weekly"
                       9 "N/A" ;
label define V33       1 "No involvement" 2 "Information" 3 "Review/comment"
                       4 "Joint planning session" 9 "N/A" ;
label define V34       1 "No involvement" 2 "Information" 3 "Review/comment"
                       4 "Joint planning session" 9 "N/A" ;
label define V35       1 "CMHC" 2 "Private clinic" 3 "Public hospital"
                       4 "Private hospital" 7 "Checked more than one" 9 "N/A" ;
label define V36       1 "Yes" 2 "No" 9 "N/A" ;
label define V37       1 "Highest priority" 6 "Lowest priority" 9 "N/A" ;
label define V38       1 "Highest priority" 6 "Lowest priority" 9 "N/A" ;
label define V39       1 "Highest priority" 6 "Lowest priority" 9 "N/A" ;
label define V40       1 "Highest priority" 6 "Lowest priority" 9 "N/A" ;
label define V41       1 "Highest priority" 6 "Lowest priority" 9 "N/A" ;
label define V42       1 "Highest priority" 6 "Lowest priority" 9 "N/A" ;
label define V43       1 "Yes" 2 "No" 9 "N/A" ;
label define V44       1 "Not at all" 2 "Limited extent" 3 "Moderate extent"
                       4 "Great extent" 9 "N/A" ;
label define V45       1 "Not responsive" 2 "Moderately responsive"
                       3 "Very responsive" 9 "N/A" ;
label define V46       1 "None" 2 "Public hearings" 3 "Lobbying"
                       4 "Advocacy groups-formal organizations"
                       5 "Needs assessment" 6 "Other" 9 "N/A" ;
label define V47       1 "Informal, personal relations"
                       2 "Attitudes, awareness, interest"
                       3 "Knowledge and information" 4 "Stability-turnover"
                       5 "Time and resources-mismanagement" 6 "Training"
                       9 "N/A" ;
label define V48       1 "Informal, personal relations"
                       2 "Attitudes, awareness, interest"
                       3 "Knowledge and information" 4 "Stability-turnover"
                       5 "Time and resources-mismanagement" 6 "Training"
                       9 "N/A" ;
label define V49       1 "Informal, personal relations"
                       2 "Attitudes, awareness, interest"
                       3 "Knowledge and information" 4 "Stability-turnover"
                       5 "Time and resources-mismanagement" 6 "Training"
                       9 "N/A" ;
label define V50       1 "Funding sources differ"
                       2 "Lack of resources-mismanagement"
                       3 "Contract for services"
                       4 "OAA does not fund MH services" 9 "N/A" ;
label define V51       1 "Funding sources differ"
                       2 "Lack of resources-mismanagement"
                       3 "Contract for services"
                       4 "OAA does not fund MH services" 9 "N/A" ;
label define V52       1 "Funding sources differ"
                       2 "Lack of resources-mismanagement"
                       3 "Contract for services"
                       4 "OAA does not fund MH services" 9 "N/A" ;
label define V53       1 "Medical Model vs. Social Service Model"
                       2 "Higher level decisions" 3 "Confidentiality"
                       4 "MH lack of outreach"
                       5 "Either MH or elderly not priority"
                       6 "Good intentions-anticipated" 9 "N/A" ;
label define V54       1 "Medical Model vs. Social Service Model"
                       2 "Higher level decisions" 3 "Confidentiality"
                       4 "MH lack of outreach"
                       5 "Either MH or elderly not priority"
                       6 "Good intentions-anticipated" 9 "N/A" ;
label define V55       1 "Medical Model vs. Social Service Model"
                       2 "Higher level decisions" 3 "Confidentiality"
                       4 "MH lack of outreach"
                       5 "Either MH or elderly not priority"
                       6 "Good intentions-anticipated" 9 "N/A" ;
label define V56       1 "Communications (contact) not routine"
                       2 "Organization Competition" 3 "Formal linkages"
                       4 "Newness of agency" 5 "Proximity, co-location"
                       6 "Other (agency closed CMHC)" 9 "N/A" ;
label define V57       1 "Communications (contact) not routine"
                       2 "Organization Competition" 3 "Formal linkages"
                       4 "Newness of agency" 5 "Proximity, co-location"
                       6 "Other (agency closed CMHC)" 9 "N/A" ;
label define V58       1 "Communications (contact) not routine"
                       2 "Organization Competition" 3 "Formal linkages"
                       4 "Newness of agency" 5 "Proximity, co-location"
                       6 "Other (agency closed CMHC)" 9 "N/A" ;
label define V59       1 "Stigma of mental illness" 2 "Stigma of elderly"
                       3 "Elderly powerless and unorganized"
                       4 "Other (community disinterest in MH prog" 9 "N/A" ;
label define V60       1 "Stigma of mental illness" 2 "Stigma of elderly"
                       3 "Elderly powerless and unorganized"
                       4 "Other (community disinterest in MH prog" 9 "N/A" ;
label define V61       1 "Stigma of mental illness" 2 "Stigma of elderly"
                       3 "Elderly powerless and unorganized"
                       4 "Other (community disinterest in MH prog" 9 "N/A" ;
label define V62       1 "Yes/no" 2 "No/no" 3 "Yes/yes" 9 "N/A" ;
label define V63       1 "Incongruent by 3" 2 "Incongruent by 2"
                       3 "Incongruent by 1" 4 "Both answered not at all"
                       5 "Both answered to a limited extent"
                       6 "Both answered to a moderate extent"
                       7 "Both answered to a great extent" 9 "N/A" ;
label define V64       1 "Yes/no" 2 "No/no" 3 "Yes/yes" 9 "N/A" ;
label define V65       1 "Incongruent by 2" 2 "Incongruent by 1"
                       3 "Both answered not at all"
                       4 "Both answered moderately responsive"
                       5 "Both answered very responsive" 9 "N/A" ;
label define V66       1 "Incongruent by 3" 2 "Incongruent by 2"
                       3 "Incongruent by 1" 4 "Both answered no contact"
                       5 "Both answered less than monthly"
                       6 "Both answered monthly" 7 "Both answered weekly"
                       9 "N/A" ;
label define V67       1 "Incongruent by 3" 2 "Incongruent by 2"
                       3 "Incongruent by 1" 4 "Both answered no involvement"
                       5 "Both answered information"
                       6 "Both answered review and comment"
                       7 "Both answered joint planning sessions" 9 "N/A" ;
label define V68       1 "Incongruent by 3" 2 "Incongruent by 2"
                       3 "Incongruent by 1" 4 "Both answered no involvement"
                       5 "Both answered information"
                       6 "Both answered review and comment"
                       7 "Both answered joint planning sessions" 9 "N/A" ;
label define V69       0 "None" 9 "Nine agencies" 99 "N/A" ;
label define V70       1 "CMHC, Mental Health Institute"
                       2 "Hospital (general, state and mental)"
                       3 "Social/community agencies"
                       4 "Local, county government agencies"
                       5 "Advocacy agencies" 6 "Planning agencies"
                       7 "Other (undefined agencies)" 9 "N/A" ;
label define V71       1 "Yes" 2 "No" 9 "N/A" ;
label define V72       1 "Yes" 2 "No" 9 "N/A" ;
label define V73       1 "Yes" 2 "No" 9 "N/A" ;
label define V74       1 "Yes" 2 "No" 9 "N/A" ;
label define V75       1 "Yes" 2 "No" 9 "N/A" ;
label define V76       1 "Yes" 2 "No" 9 "N/A" ;
label define V77       1 "CMHC, Mental Health Institute"
                       2 "Hospital (general, state and mental)"
                       3 "Social/community agencies"
                       4 "Local, county government agencies"
                       5 "Advocacy agencies" 6 "Planning agencies"
                       7 "Other (undefined agencies)" 9 "N/A" ;
label define V78       1 "Yes" 2 "No" 9 "N/A" ;
label define V79       1 "Yes" 2 "No" 9 "N/A" ;
label define V80       1 "Yes" 2 "No" 9 "N/A" ;
label define V81       1 "Yes" 2 "No" 9 "N/A" ;
label define V82       1 "Yes" 2 "No" 9 "N/A" ;
label define V83       1 "Yes" 2 "No" 9 "N/A" ;
label define V84       1 "CMHC, Mental Health Institute"
                       2 "Hospital (general, state and mental)"
                       3 "Social/community agencies"
                       4 "Local, county government agencies"
                       5 "Advocacy agencies" 6 "Planning agencies"
                       7 "Other (undefined agencies)" 9 "N/A" ;
label define V85       1 "Yes" 2 "No" 9 "N/A" ;
label define V86       1 "Yes" 2 "No" 9 "N/A" ;
label define V87       1 "Yes" 2 "No" 9 "N/A" ;
label define V88       1 "Yes" 2 "No" 9 "N/A" ;
label define V89       1 "Yes" 2 "No" 9 "N/A" ;
label define V90       1 "Yes" 2 "No" 9 "N/A" ;
label define V91       1 "CMHC, Mental Health Institute"
                       2 "Hospital (general, state and mental)"
                       3 "Social/community agencies"
                       4 "Local, county government agencies"
                       5 "Advocacy agencies" 6 "Planning agencies"
                       7 "Other (undefined agencies)" 9 "N/A" ;
label define V92       1 "Yes" 2 "No" 9 "N/A" ;
label define V93       1 "Yes" 2 "No" 9 "N/A" ;
label define V94       1 "Yes" 2 "No" 9 "N/A" ;
label define V95       1 "Yes" 2 "No" 9 "N/A" ;
label define V96       1 "Yes" 2 "No" 9 "N/A" ;
label define V97       1 "Yes" 2 "No" 9 "N/A" ;
label define V98       1 "CMHC, Mental Health Institute"
                       2 "Hospital (general, state and mental)"
                       3 "Social/community agencies"
                       4 "Local, county government agencies"
                       5 "Advocacy agencies" 6 "Planning agencies"
                       7 "Other (undefined agencies)" 9 "N/A" ;
label define V99       1 "Yes" 2 "No" 9 "N/A" ;
label define V100      1 "Yes" 2 "No" 9 "N/A" ;
label define V101      1 "Yes" 2 "No" 9 "N/A" ;
label define V102      1 "Yes" 2 "No" 9 "N/A" ;
label define V103      1 "Yes" 2 "No" 9 "N/A" ;
label define V104      1 "Yes" 2 "No" 9 "N/A" ;
label define V105      1 "CMHC, Mental Health Institute"
                       2 "Hospital (general, state and mental)"
                       3 "Social/community agencies"
                       4 "Local, county government agencies"
                       5 "Advocacy agencies" 6 "Planning agencies"
                       7 "Other (undefined agencies)" 9 "N/A" ;
label define V106      1 "Yes" 2 "No" 9 "N/A" ;
label define V107      1 "Yes" 2 "No" 9 "N/A" ;
label define V108      1 "Yes" 2 "No" 9 "N/A" ;
label define V109      1 "Yes" 2 "No" 9 "N/A" ;
label define V110      1 "Yes" 2 "No" 9 "N/A" ;
label define V111      1 "Yes" 2 "No" 9 "N/A" ;
label define V112      1 "CMHC, Mental Health Institute"
                       2 "Hospital (general, state and mental)"
                       3 "Social/community agencies"
                       4 "Local, county government agencies"
                       5 "Advocacy agencies" 6 "Planning agencies"
                       7 "Other (undefined agencies)" 9 "N/A" ;
label define V113      1 "Yes" 2 "No" 9 "N/A" ;
label define V114      1 "Yes" 2 "No" 9 "N/A" ;
label define V115      1 "Yes" 2 "No" 9 "N/A" ;
label define V116      1 "Yes" 2 "No" 9 "N/A" ;
label define V117      1 "Yes" 2 "No" 9 "N/A" ;
label define V118      1 "Yes" 2 "No" 9 "N/A" ;
label define V119      1 "CMHC, Mental Health Institute"
                       2 "Hospital (general, state and mental)"
                       3 "Social/community agencies"
                       4 "Local, county government agencies"
                       5 "Advocacy agencies" 6 "Planning agencies"
                       7 "Other (undefined agencies)" 9 "N/A" ;
label define V120      1 "Yes" 2 "No" 9 "N/A" ;
label define V121      1 "Yes" 2 "No" 9 "N/A" ;
label define V122      1 "Yes" 2 "No" 9 "N/A" ;
label define V123      1 "Yes" 2 "No" 9 "N/A" ;
label define V124      1 "Yes" 2 "No" 9 "N/A" ;
label define V125      1 "Yes" 2 "No" 9 "N/A" ;
label define V126      1 "CMHC, Mental Health Institute"
                       2 "Hospital (general, state and mental)"
                       3 "Social/community agencies"
                       4 "Local, county government agencies"
                       5 "Advocacy agencies" 6 "Planning agencies"
                       7 "Other (undefined agencies)" 9 "N/A" ;
label define V127      1 "Yes" 2 "No" 9 "N/A" ;
label define V128      1 "Yes" 2 "No" 9 "N/A" ;
label define V129      1 "Yes" 2 "No" 9 "N/A" ;
label define V130      1 "Yes" 2 "No" 9 "N/A" ;
label define V131      1 "Yes" 2 "No" 9 "N/A" ;
label define V132      1 "Yes" 2 "No" 9 "N/A" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.

****************************************************************/

/*
replace V8 = . if (V8 == 99)
replace V9 = . if (V9 == 9)
replace V10 = . if (V10 == 99999)
replace V11 = . if (V11 == 9999)
replace V12 = . if (V12 == 99)
replace V13 = . if (V13 == 999)
replace V14 = . if (V14 == 999)
replace V15 = . if (V15 == 99)
replace V16 = . if (V16 == 999)
replace V17 = . if (V17 == 999)
replace V18 = . if (V18 == 999)
replace V19 = . if (V19 == 999)
replace V20 = . if (V20 == 9)
replace V21 = . if (V21 == 999)
replace V22 = . if (V22 == 999)
replace V23 = . if (V23 == 999)
replace V24 = . if (V24 == 999)
replace V25 = . if (V25 == 999)
replace V26 = . if (V26 == 999)
replace V27 = . if (V27 == 999)
replace V28 = . if (V28 == 9)
replace V29 = . if (V29 == 9)
replace V30 = . if (V30 == 9)
replace V31 = . if (V31 == 9)
replace V32 = . if (V32 == 9)
replace V33 = . if (V33 == 9)
replace V34 = . if (V34 == 9)
replace V35 = . if (V35 == 9)
replace V36 = . if (V36 == 9)
replace V37 = . if (V37 == 9)
replace V38 = . if (V38 == 9)
replace V39 = . if (V39 == 9)
replace V40 = . if (V40 == 9)
replace V41 = . if (V41 == 9)
replace V42 = . if (V42 == 9)
replace V43 = . if (V43 == 9)
replace V44 = . if (V44 == 9)
replace V45 = . if (V45 == 9)
replace V46 = . if (V46 == 9)
replace V47 = . if (V47 == 9)
replace V48 = . if (V48 == 9)
replace V49 = . if (V49 == 9)
replace V50 = . if (V50 == 9)
replace V51 = . if (V51 == 9)
replace V52 = . if (V52 == 9)
replace V53 = . if (V53 == 9)
replace V54 = . if (V54 == 9)
replace V55 = . if (V55 == 9)
replace V56 = . if (V56 == 9)
replace V57 = . if (V57 == 9)
replace V58 = . if (V58 == 9)
replace V59 = . if (V59 == 9)
replace V60 = . if (V60 == 9)
replace V61 = . if (V61 == 9)
replace V62 = . if (V62 == 9)
replace V63 = . if (V63 == 9)
replace V64 = . if (V64 == 9)
replace V65 = . if (V65 == 9)
replace V66 = . if (V66 == 9)
replace V67 = . if (V67 == 9)
replace V68 = . if (V68 == 9)
replace V69 = . if (V69 == 99)
replace V70 = . if (V70 == 9)
replace V71 = . if (V71 == 9)
replace V72 = . if (V72 == 9)
replace V73 = . if (V73 == 9)
replace V74 = . if (V74 == 9)
replace V75 = . if (V75 == 9)
replace V76 = . if (V76 == 9)
replace V77 = . if (V77 == 9)
replace V78 = . if (V78 == 9)
replace V79 = . if (V79 == 9)
replace V80 = . if (V80 == 9)
replace V81 = . if (V81 == 9)
replace V82 = . if (V82 == 9)
replace V83 = . if (V83 == 9)
replace V84 = . if (V84 == 9)
replace V85 = . if (V85 == 9)
replace V86 = . if (V86 == 9)
replace V87 = . if (V87 == 9)
replace V88 = . if (V88 == 9)
replace V89 = . if (V89 == 9)
replace V90 = . if (V90 == 9)
replace V91 = . if (V91 == 9)
replace V92 = . if (V92 == 9)
replace V93 = . if (V93 == 9)
replace V94 = . if (V94 == 9)
replace V95 = . if (V95 == 9)
replace V96 = . if (V96 == 9)
replace V97 = . if (V97 == 9)
replace V98 = . if (V98 == 9)
replace V99 = . if (V99 == 9)
replace V100 = . if (V100 == 9)
replace V101 = . if (V101 == 9)
replace V102 = . if (V102 == 9)
replace V103 = . if (V103 == 9)
replace V104 = . if (V104 == 9)
replace V105 = . if (V105 == 9)
replace V106 = . if (V106 == 9)
replace V107 = . if (V107 == 9)
replace V108 = . if (V108 == 9)
replace V109 = . if (V109 == 9)
replace V110 = . if (V110 == 9)
replace V111 = . if (V111 == 9)
replace V112 = . if (V112 == 9)
replace V113 = . if (V113 == 9)
replace V114 = . if (V114 == 9)
replace V115 = . if (V115 == 9)
replace V116 = . if (V116 == 9)
replace V117 = . if (V117 == 9)
replace V118 = . if (V118 == 9)
replace V119 = . if (V119 == 9)
replace V120 = . if (V120 == 9)
replace V121 = . if (V121 == 9)
replace V122 = . if (V122 == 9)
replace V123 = . if (V123 == 9)
replace V124 = . if (V124 == 9)
replace V125 = . if (V125 == 9)
replace V126 = . if (V126 == 9)
replace V127 = . if (V127 == 9)
replace V128 = . if (V128 == 9)
replace V129 = . if (V129 == 9)
replace V130 = . if (V130 == 9)
replace V131 = . if (V131 == 9)
replace V132 = . if (V132 == 9)


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

